@@ -175,6 +175,14 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 				s->Phone.Functions = &ALCATELPhone;
 				return ERR_NONE;
 			}
+#endif
+#ifdef GSM_ENABLE_SONYERICSSON
+			/* If phone provides Sony-Ericsson specific functions, enable them */
+			if (model->model[0] != 0 && IsPhoneFeatureAvailable(model, F_OBEX)) {
+				smprintf(s,"[Module           - \"%s\"]\n",SONYERICSSONPhone.models);
+				s->Phone.Functions = &SONYERICSSONPhone;
+				return ERR_NONE;
+			}
 #endif
 			smprintf(s,"[Module           - \"%s\"]\n",ATGENPhone.models);
 			s->Phone.Functions = &ATGENPhone;
@@ -220,6 +228,9 @@ GSM_Error GSM_RegisterAllPhoneModules(GSM_StateMachine *s)
 #endif
 #ifdef GSM_ENABLE_ALCATEL
 	GSM_RegisterModule(s,&ALCATELPhone);
+#endif
+#ifdef GSM_ENABLE_SONYERICSSON
+	GSM_RegisterModule(s,&SONYERICSSONPhone);
 #endif
 	if (s->Phone.Functions==NULL) return ERR_UNKNOWNMODELSTRING;
 	return ERR_NONE;
@@ -877,6 +888,42 @@ bool GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 		cfg->StartInfo			 = strdup(cfg->StartInfo);
 		cfg->DefaultStartInfo 		 = false;
 	}
+
+	Temp		 = INI_GetValue(cfg_info, section, "reminder", 		false);
+	if (!Temp) {
+		strcpy(cfg->TextReminder,"Reminder");
+	} else {
+		strcpy(cfg->TextReminder,Temp);
+	}
+
+	Temp		 = INI_GetValue(cfg_info, section, "meeting", 		false);
+	if (!Temp) {
+		strcpy(cfg->TextMeeting,"Meeting");
+	} else {
+		strcpy(cfg->TextMeeting,Temp);
+	}
+
+	Temp		 = INI_GetValue(cfg_info, section, "call", 		false);
+	if (!Temp) {
+		strcpy(cfg->TextCall,"Call");
+	} else {
+		strcpy(cfg->TextCall,Temp);
+	}
+
+	Temp		 = INI_GetValue(cfg_info, section, "birthday", 		false);
+	if (!Temp) {
+		strcpy(cfg->TextBirthday,"Birthday");
+	} else {
+		strcpy(cfg->TextBirthday,Temp);
+	}
+
+	Temp		 = INI_GetValue(cfg_info, section, "memo", 		false);
+	if (!Temp) {
+		strcpy(cfg->TextMemo,"Memo");
+	} else {
+		strcpy(cfg->TextMemo,Temp);
+	}
+
 	return true;
 }
 
@@ -929,6 +976,7 @@ static OnePhoneModel allmodels[] = {
 	{"3108", "RH-6",  "Nokia 3108",	{0}}, //does it have irda ?
 	{"3200", "RH-30" ,"Nokia 3200",	{F_PBKTONEGAL,0}},//fixme
 	{"3200a","RH-31" ,"Nokia 3200",	{F_PBKTONEGAL,0}},//fixme
+ 	{"3205", "RM-11" ,"Nokia 3205",	{F_CAL62,F_PBK35,F_NOGPRSPOINT,F_VOICETAGS,F_PROFILES,F_RADIO,F_PBKSMSLIST,F_PBKTONEGAL,0}},//fixme
 	{"3300" ,"NEM-1" ,"Nokia 3300", {F_PBKTONEGAL,0}},//fixme
 	{"3300" ,"NEM-2" ,"Nokia 3300", {F_PBKTONEGAL,0}},//fixme
 	{"3510" ,"NHM-8" ,"",           {F_CAL35,F_PBK35,F_NOGPRSPOINT,F_VOICETAGS,0}},
@@ -949,9 +997,10 @@ static OnePhoneModel allmodels[] = {
 	{"5140i","RM-104","Nokia 5140i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKUSER,F_WAPMMSPROXY,F_CHAT, F_SYNCML,0}},
 	{"6020" ,"RM-30" ,"Nokia 6020", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES,0}},//quess
 	{"6021" ,"RM-94" ,"Nokia 6021", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,F_6230iWAP,F_6230iCALLER,0}},//quess
+	{"6030" ,"RM-74" ,"Nokia 6030", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES,F_FILES2,F_NOFILE1,0}},//quess
 	{"6100" ,"NPL-2" ,"Nokia 6100", {F_PBKTONEGAL,F_TODO66,0}},
 	{"6101" ,"RM-76" ,"Nokia 6101", {F_PBKTONEGAL,F_TODO66,0}},
-	{"6103" ,"RM-161","Nokia 6103", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},//fixme
+	{"6103" ,"RM-161","Nokia 6103", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_NOFILE1,0}},//fixme
 	{"6111" ,"RM-82" ,"Nokia 6111", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
 	{"6125" ,"RM-178","Nokia 6125", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},//fixme
 	{"6131" ,"RM-115","Nokia 6131", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},//fixme
@@ -963,6 +1012,7 @@ static OnePhoneModel allmodels[] = {
 	{"6230" ,"RH-28" ,"Nokia 6230", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"6230i","RM-72" ,"Nokia 6230i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,F_6230iWAP,F_6230iCALLER,0}},
 	{"6233" ,"RM-145","Nokia 6233", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},//fixme
+	{"6234" ,"RM-123","Nokia 6234", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},//fixme
 	{"6270" ,"RM-56","Nokia 6270", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},//fixme
 	{"6280" ,"RM-78","Nokia 6280", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},//fixme
 	{"6310" ,"NPE-4" ,"Nokia 6310", {F_TODO63,F_CAL65,F_NOMIDI,F_NOMMS,F_VOICETAGS,0}},
@@ -1015,6 +1065,7 @@ static OnePhoneModel allmodels[] = {
 	{"S40" ,	  "Siemens S40",  "",			   	   {0}},
 	{"C45" ,	  "C45",	  "",				   {0}},
 	{"S45" ,	  "S45",	  "",				   {0}},
+	{"S45i" ,	  "S45i",	  "",				   {0}},
 	{"ME45" ,	  "ME45", 	  "SIEMENS ME45",		   {0}},
 	{"SL45" ,	  "SL45",	  "",				   {0}},
 	{"SL45i" ,	  "SL45i",	  "",				   {0}},
@@ -1031,20 +1082,238 @@ static OnePhoneModel allmodels[] = {
 	{"V200" ,	  "SGH-V200" ,    "",				   {0}},
 	{"T100" ,	  "SGH-T100" ,    "",				   {0}},
 	{"E700" ,	  "SGH-E700" ,    "",				   {0}},
+
 	/* Ericsson/Sony Ericsson */
-	{"T28s",	"1101101-BVT28s","",				   {0}},
-	{"R320s" ,	"1101201-BV R320s","",				   {0}},
-	{"R380s",	"7100101-BVR380s" ,"",				   {0}},
-	{"R520m",	"1130101-BVR520m" ,"",				   {0}},
-	{"T39m",	"1130102-BVT39m" ,"",				   {0}},
-	{"T65",		"1101901-BVT65" , "",				   {0}},
-	{"T68",		"1130201-BVT68" , "",				   {0}},
-	{"T68i",	"1130202-BVT68" , "",				   {0}},
-	{"R600",	"102001-BVR600" , "",				   {0}},
-	{"T200",	"1130501-BVT200" ,"",				   {0}},
-	{"T300",	"1130601-BVT300" ,"T300",			   {0}},
-	{"T310",	"1130602-BVT310" ,"",			   	   {0}},
-	{"P800",	"7130501-BVP800" ,"",				   {0}},
+	{"T28s",	"1101101-BVT28s","",				   {F_OBEX, 0}},
+	{"R320s" ,	"1101201-BV R320s","",				   {F_OBEX, 0}},
+	{"R380s",	"7100101-BVR380s" ,"",				   {F_OBEX, 0}},
+	{"R520m",	"1130101-BVR520m" ,"",				   {F_OBEX, 0}},
+	{"T39m",	"1130102-BVT39m" ,"",				   {F_OBEX, 0}},
+	{"T65",		"1101901-BVT65" , "",				   {F_OBEX, 0}},
+	{"T68",		"1130201-BVT68" , "",				   {F_OBEX, 0}},
+	{"T68i",	"1130202-BVT68" , "",				   {F_OBEX, 0}},
+	{"R600",	"102001-BVR600" , "",				   {F_OBEX, 0}},
+	{"T200",	"1130501-BVT200" ,"",				   {F_OBEX, 0}},
+	{"T300",	"1130601-BVT300" ,"T300",			   {F_OBEX, 0}},
+	{"T310",	"1130602-BVT310" ,"",			   	   {F_OBEX, 0}},
+	{"P800",	"7130501-BVP800" ,"",				   {F_OBEX, 0}},
+
+	/* Ericsson/Sony Ericsson till 2003, not verified */
+	{"T106",	"1022101-BV" ,"",				   {F_OBEX, 0}},
+	{"SH888",	"1100801-BV" ,"",				   {F_OBEX, 0}},
+	{"R250s PRO",	"1100802-BV" ,"",				   {F_OBEX, 0}},
+	{"A1018s",	"1100901-BV" ,"",				   {F_OBEX, 0}},
+	{"A1018sc",	"1100901-CN" ,"",				   {F_OBEX, 0}},
+	{"A1028s",	"1100902-BV" ,"",				   {F_OBEX, 0}},
+	{"A1028sc",	"1100902-CN" ,"",				   {F_OBEX, 0}},
+	{"T18s",	"1101001-BV" ,"",				   {F_OBEX, 0}},
+	{"T18sc",	"1101001-CN" ,"",				   {F_OBEX, 0}},
+	{"T10s",	"1101002-BV" ,"",				   {F_OBEX, 0}},
+	{"T10sc",	"1101002-CN" ,"",				   {F_OBEX, 0}},
+	{"T28s",	"1101101-BC" ,"",				   {F_OBEX, 0}},
+	{"T28sc",	"1101101-CN" ,"",				   {F_OBEX, 0}},
+	{"R310s",	"1101102-BC" ,"",				   {F_OBEX, 0}},
+	{"R310sc",	"1101102-CN" ,"",				   {F_OBEX, 0}},
+	{"R320s",	"1101201-BV" ,"",				   {F_OBEX, 0}},
+	{"R320sc",	"1101201-CN" ,"",				   {F_OBEX, 0}},
+	{"T20e",	"1101401-BV" ,"",				   {F_OBEX, 0}},
+	{"T20ec",	"1101401-CN" ,"",				   {F_OBEX, 0}},
+	{"A2618s",	"1101501-BV" ,"",				   {F_OBEX, 0}},
+	{"A2618sc",	"1101501-CN" ,"",				   {F_OBEX, 0}},
+	{"A2628s",	"1101502-BV" ,"",				   {F_OBEX, 0}},
+	{"A2628sc",	"1101502-CN" ,"",				   {F_OBEX, 0}},
+	{"T29s",	"1101601-BV" ,"",				   {F_OBEX, 0}},
+	{"T29sc",	"1101601-CN" ,"",				   {F_OBEX, 0}},
+	{"A3618s",	"1101801-BV" ,"",				   {F_OBEX, 0}},
+	{"A3618sc",	"1101801-CN" ,"",				   {F_OBEX, 0}},
+	{"T65",		"1101901-CN" ,"",				   {F_OBEX, 0}},
+	{"T65",		"1101901-BV" ,"",				   {F_OBEX, 0}},
+	{"R600",	"1102001-BV" ,"",				   {F_OBEX, 0}},
+	{"R602",	"1102001-CN" ,"",				   {F_OBEX, 0}},
+	{"T100",	"1102101-BV" ,"",				   {F_OBEX, 0}},
+	{"T102/T105",	"1102101-CN" ,"",				   {F_OBEX, 0}},
+	{"R520m",	"1130101-BV" ,"",				   {F_OBEX, 0}},
+	{"R520mc",	"1130101-CN" ,"",				   {F_OBEX, 0}},
+	{"T39m",	"1130102-BV" ,"",				   {F_OBEX, 0}},
+	{"T39mc",	"1130102-CN" ,"",				   {F_OBEX, 0}},
+	{"T68",		"1130201-BV" ,"",				   {F_OBEX, 0}},
+	{"T68",		"1130201-CN" ,"",				   {F_OBEX, 0}},
+	{"T68i",	"1130202-BV" ,"",				   {F_OBEX, 0}},
+	{"T68ie",	"1130202-CN" ,"",				   {F_OBEX, 0}},
+	{"T66",		"1130401-CN" ,"",				   {F_OBEX, 0}},
+	{"T66",		"1130401-BV" ,"",				   {F_OBEX, 0}},
+	{"T600",	"1130402-BV" ,"",				   {F_OBEX, 0}},
+	{"T602",	"1130402-CN" ,"",				   {F_OBEX, 0}},
+	{"T200",	"1130501-BV" ,"",				   {F_OBEX, 0}},
+	{"T202",	"1130501-CN" ,"",				   {F_OBEX, 0}},
+	{"T300",	"1130601-BV" ,"",				   {F_OBEX, 0}},
+	{"T302",	"1130601-CN" ,"",				   {F_OBEX, 0}},
+	{"T310",	"1130602-BV" ,"",				   {F_OBEX, 0}},
+	{"T312",	"1130602-CN" ,"",				   {F_OBEX, 0}},
+	{"T28 WORLD",	"1141101-BV" ,"",				   {F_OBEX, 0}},
+	{"R190",	"1150101-BV" ,"",				   {F_OBEX, 0}},
+	{"R290",	"1180101-BV" ,"",				   {F_OBEX, 0}},
+	{"T106",	"1222101-BV" ,"",				   {F_OBEX, 0}},
+	{"T608",	"1250101-BV" ,"",				   {F_OBEX, 0}},
+	{"T306",	"1260101-BV" ,"",				   {F_OBEX, 0}},
+	{"T316",	"1260102-BV" ,"",				   {F_OBEX, 0}},
+	{"T106 850",	"1272101-BV" ,"",				   {F_OBEX, 0}},
+	{"GM12",	"6050102-BV" ,"",				   {F_OBEX, 0}},
+	{"GM22",	"6100201-BV" ,"",				   {F_OBEX, 0}},
+	{"GM25",	"6100202-BV" ,"",				   {F_OBEX, 0}},
+	{"GM47",	"6100501-BV" ,"",				   {F_OBEX, 0}},
+	{"GM27",	"6100502-BV" ,"",				   {F_OBEX, 0}},
+	{"GM29",	"6100503-BV" ,"",				   {F_OBEX, 0}},
+	{"GM41",	"6100504-BV" ,"",				   {F_OBEX, 0}},
+	{"GR47",	"6100511-BV" ,"",				   {F_OBEX, 0}},
+	{"GC75",	"6130201-BV" ,"",				   {F_OBEX, 0}},
+	{"GC25",	"6150101-BV" ,"",				   {F_OBEX, 0}},
+	{"GM48",	"6220501-BV" ,"",				   {F_OBEX, 0}},
+	{"GM28",	"6220502-BV" ,"",				   {F_OBEX, 0}},
+	{"GR48",	"6220511-BV" ,"",				   {F_OBEX, 0}},
+	{"R380s",	"7100101-BV" ,"",				   {F_OBEX, 0}},
+	{"R380sc",	"7100101-CN" ,"",				   {F_OBEX, 0}},
+	{"P800",	"7130501-BV" ,"",				   {F_OBEX, 0}},
+	{"P802",	"7130501-CN" ,"",				   {F_OBEX, 0}},
+	{"R380s world",	"7140101-BV" ,"",				   {F_OBEX, 0}},
+
+/* Sony-Ericsson since 2003, partly not verified  */
+	{"T230",	"AAA-1001012-BV" ,"",				   {F_OBEX, 0}},
+	{"T228",	"AAA-1001012-CN" ,"",				   {F_OBEX, 0}},
+	{"T290i",	"AAA-1001013-BV" ,"",				   {F_OBEX, 0}},
+	{"T290c",	"AAA-1001013-CN" ,"",				   {F_OBEX, 0}},
+	{"J300i",	"AAA-1001021-BV" ,"",				   {F_OBEX, 0}},
+	{"J300c",	"AAA-1001021-CN" ,"",				   {F_OBEX, 0}},
+	{"Z300i",	"AAA-1001031-BV" ,"",				   {F_OBEX, 0}},
+	{"Z300c",	"AAA-1001031-CN" ,"",				   {F_OBEX, 0}},
+	{"J230i",	"AAA-1002011-BV" ,"",				   {F_OBEX, 0}},
+	{"J230c",	"AAA-1002011-CN" ,"",				   {F_OBEX, 0}},
+	{"J220i",	"AAA-1002012-BV" ,"",				   {F_OBEX, 0}},
+	{"J220c",	"AAA-1002012-CN" ,"",				   {F_OBEX, 0}},
+	{"J100i",	"AAA-1002021-BV" ,"",				   {F_OBEX, 0}},
+	{"J100c",	"AAA-1002021-CN" ,"",				   {F_OBEX, 0}},
+	{"T226",	"AAA-1041011-BV" ,"",				   {F_OBEX, 0}},
+	{"T226s/T237m",	"AAA-1041012-BV" ,"",				   {F_OBEX, 0}},
+	{"J300a",	"AAA-1041021-BV" ,"",				   {F_OBEX, 0}},
+	{"Z300a",	"AAA-1041031-BV" ,"",				   {F_OBEX, 0}},
+	{"J230a",	"AAA-1042011-BV" ,"",				   {F_OBEX, 0}},
+	{"J220a",	"AAA-1042012-BV" ,"",				   {F_OBEX, 0}},
+	{"J100a",	"AAA-1042021-BV" ,"",				   {F_OBEX, 0}},
+	{"T292a",	"AAA-1061011-BV" ,"",				   {F_OBEX, 0}},
+	{"T610",	"AAB-1021011-BV" ,"",				   {F_OBEX, 0}},
+	{"T618",	"AAB-1021011-CN" ,"",				   {F_OBEX, 0}},
+	{"T630",	"AAB-1021012-BV" ,"",				   {F_OBEX, 0}},
+	{"T628",	"AAB-1021012-CN" ,"",				   {F_OBEX, 0}},
+	{"Z200",	"AAB-1021021-BV" ,"",				   {F_OBEX, 0}},
+	{"Z208",	"AAB-1021021-CN" ,"",				   {F_OBEX, 0}},
+	{"Z600",	"AAB-1021031-BV" ,"",				   {F_OBEX, 0}},
+	{"Z608",	"AAB-1021031-CN" ,"",				   {F_OBEX, 0}},
+	{"K700i",	"AAB-1021041-BV" ,"",				   {F_OBEX, 0}},
+	{"K700c",	"AAB-1021041-CN" ,"",				   {F_OBEX, 0}},
+	{"F500i",	"AAB-1021042-BV" ,"",				   {F_OBEX, 0}},
+	{"K506c",	"AAB-1021042-CN" ,"",				   {F_OBEX, 0}},
+	{"K500i",	"AAB-1021043-BV" ,"",				   {F_OBEX, 0}},
+	{"K500c",	"AAB-1021043-CN" ,"",				   {F_OBEX, 0}},
+	{"K508i",	"AAB-1021044-BV" ,"",				   {F_OBEX, 0}},
+	{"K508c",	"AAB-1021044-CN" ,"",				   {F_OBEX, 0}},
+	{"S700i",	"AAB-1021051-BV" ,"",				   {F_OBEX, 0}},
+	{"S700c",	"AAB-1021051-CN" ,"",				   {F_OBEX, 0}},
+	{"J200i",	"AAB-1021061-BV" ,"",				   {F_OBEX, 0}},
+	{"J200c",	"AAB-1021061-CN" ,"",				   {F_OBEX, 0}},
+	{"J210i",	"AAB-1021062-BV" ,"",				   {F_OBEX, 0}},
+	{"J210c",	"AAB-1021062-CN" ,"",				   {F_OBEX, 0}},
+	{"K300i",	"AAB-1021071-BV" ,"",				   {F_OBEX, 0}},
+	{"K300c",	"AAB-1021071-CN" ,"",				   {F_OBEX, 0}},
+	{"K750i",	"AAB-1022011-BV" ,"",				   {F_OBEX, 0}},
+	{"K750c",	"AAB-1022011-CN" ,"",				   {F_OBEX, 0}},
+	{"D750i/K758c",	"AAB-1022012-BV" ,"",				   {F_OBEX, 0}},
+	{"W800i",	"AAB-1022013-BV" ,"",				   {F_OBEX, 0}},
+	{"W800c",	"AAB-1022013-CN" ,"",				   {F_OBEX, 0}},
+	{"W700i",	"AAB-1022014-BV" ,"",				   {F_OBEX, 0}},
+	{"W700c",	"AAB-1022014-CN" ,"",				   {F_OBEX, 0}},
+	{"Z550i",	"AAB-1022015-BV" ,"",				   {F_OBEX, 0}},
+	{"Z550c",	"AAB-1022015-CN" ,"",				   {F_OBEX, 0}},
+	{"Z558i",	"AAB-1022016-BV" ,"",				   {F_OBEX, 0}},
+	{"Z558c",	"AAB-1022016-CN" ,"",				   {F_OBEX, 0}},
+	{"W550i",	"AAB-1022021-BV" ,"",				   {F_OBEX, 0}},
+	{"W550c",	"AAB-1022021-CN" ,"",				   {F_OBEX, 0}},
+	{"Z530i",	"AAB-1022031-BV" ,"",				   {F_OBEX, 0}},
+	{"Z530c",	"AAB-1022031-CN" ,"",				   {F_OBEX, 0}},
+	{"K510i",	"AAB-1022041-BV" ,"",				   {F_OBEX, 0}},
+	{"K510c",	"AAB-1022041-CN" ,"",				   {F_OBEX, 0}},
+	{"K310i",	"AAB-1022042-BV" ,"",				   {F_OBEX, 0}},
+	{"K310c",	"AAB-1022042-CN" ,"",				   {F_OBEX, 0}},
+	{"K320i/K320c",	"AAB-1022043-BV" ,"",				   {F_OBEX, 0}},
+	{"T616",	"AAB-1031011-BV" ,"",				   {F_OBEX, 0}},
+	{"T637",	"AAB-1031012-BV" ,"",				   {F_OBEX, 0}},
+	{"K300a",	"AAB-1031021-BV" ,"",				   {F_OBEX, 0}},
+	{"K510a",	"AAB-1032011-BV" ,"",				   {F_OBEX, 0}},
+	{"K310a",	"AAB-1032012-BV" ,"",				   {F_OBEX, 0}},
+	{"Z520i",	"AAC-1052011-BV" ,"",				   {F_OBEX, 0}},
+	{"Z520c",	"AAC-1052011-CN" ,"",				   {F_OBEX, 0}},
+	{"Z520a",	"AAC-1052012-BV" ,"",				   {F_OBEX, 0}},
+	{"Z525i",	"AAC-1052013-BV" ,"",				   {F_OBEX, 0}},
+	{"Z525a",	"AAC-1052014-BV" ,"",				   {F_OBEX, 0}},
+	{"Z550a",	"AAC-1052031-BV" ,"",				   {F_OBEX, 0}},
+	{"Z1010",	"AAD-3011011-BV" ,"",				   {F_OBEX, 0}},
+	{"V800/V802SE/Z800i",	"AAD-3021011-BV" ,"",			   {F_OBEX, 0}},
+	{"K600i",	"AAD-3021021-BV" ,"",				   {F_OBEX, 0}},
+	{"V600i",	"AAD-3021022-BV" ,"",				   {F_OBEX, 0}},
+	{"K608i",	"AAD-3021023-BV" ,"",				   {F_OBEX, 0}},
+	{"W900i",	"AAD-3022011-BV" ,"",				   {F_OBEX, 0}},
+	{"W850i",	"AAD-3022021-BV" ,"",				   {F_OBEX, 0}},
+	{"K800i/K800c",	"AAD-3022031-BV" ,"",				   {F_OBEX, 0}},
+	{"K610i",	"AAD-3022041-BV" ,"",				   {F_OBEX, 0}},
+	{"K618i/V630i",	"AAD-3022042-BV" ,"",				   {F_OBEX, 0}},
+	{"K610im",	"AAD-3022043-BV" ,"",				   {F_OBEX, 0}},
+	{"Z610i",	"AAD-3022044-BV" ,"",				   {F_OBEX, 0}},
+	{"K790i",	"AAF-1022011-BV" ,"",				   {F_OBEX, 0}},
+	{"K790c",	"AAF-1022011-CN" ,"",				   {F_OBEX, 0}},
+	{"Z500a",	"AAF-1031011-BV" ,"",				   {F_OBEX, 0}},
+	{"S710a",	"AAF-1031021-BV" ,"",				   {F_OBEX, 0}},
+	{"K790a",	"AAF-1032011-BV" ,"",				   {F_OBEX, 0}},
+	{"W712a",	"AAF-1042011-BV" ,"",				   {F_OBEX, 0}},
+	{"Z712a",	"AAF-1042012-BV" ,"",				   {F_OBEX, 0}},
+	{"W600a/W600c/W600i",	"AAF-1052021-BV" ,"",			   {F_OBEX, 0}},
+	{"W300i",	"AAF-1052031-BV" ,"",				   {F_OBEX, 0}},
+	{"W300c",	"AAF-1052031-CN" ,"",				   {F_OBEX, 0}},
+	{"W710i/W710c",	"AAF-1052041-BV" ,"",				   {F_OBEX, 0}},
+	{"Z710i/Z710c",	"AAF-1052043-BV" ,"",				   {F_OBEX, 0}},
+	{"W810i",	"AAF-1052051-BV" ,"",				   {F_OBEX, 0}},
+	{"W810c",	"AAF-1052051-CN" ,"",				   {F_OBEX, 0}},
+	{"Z502a",	"AAF-1061011-BV" ,"",				   {F_OBEX, 0}},
+	{"GR64",	"BAC-1051012-BV" ,"",				   {F_OBEX, 0}},
+	{"GS64",	"BAC-1051022-BV" ,"",				   {F_OBEX, 0}},
+	{"GA64",	"BAC-1051023-BV" ,"",				   {F_OBEX, 0}},
+	{"CM52",	"BAE-4001011-BV" ,"",				   {F_OBEX, 0}},
+	{"M52",	"BAE-4001012-BV" ,"",				   {F_OBEX, 0}},
+	{"GC82",	"FAA-1041011-BV" ,"",				   {F_OBEX, 0}},
+	{"P900",	"FAB-1021011-BV" ,"",				   {F_OBEX, 0}},
+	{"P908",	"FAB-1021011-CN" ,"",				   {F_OBEX, 0}},
+	{"P910i",	"FAB-1021012-BV" ,"",				   {F_OBEX, 0}},
+	{"P910c",	"FAB-1021012-CN" ,"",				   {F_OBEX, 0}},
+	{"M608c",	"FAB-1022011-BV" ,"",				   {F_OBEX, 0}},
+	{"W958c",	"FAB-1022012-BV" ,"",				   {F_OBEX, 0}},
+	{"P910a",	"FAB-1031012-BV" ,"",				   {F_OBEX, 0}},
+	{"P990i",	"FAD-3022011-BV" ,"",				   {F_OBEX, 0}},
+	{"M600i",	"FAD-3022012-BV" ,"",				   {F_OBEX, 0}},
+	{"W950i",	"FAD-3022013-BV" ,"",				   {F_OBEX, 0}},
+	{"GC99",	"FAD-3031012-BV" ,"",				   {F_OBEX, 0}},
+	{"GC79",	"FAE-1021011-BV" ,"",				   {F_OBEX, 0}},
+	{"GC85",	"FAF-1021011-BV" ,"",				   {F_OBEX, 0}},
+	{"GC83",	"FAF-1031011-BV" ,"",				   {F_OBEX, 0}},
+	{"VDC",		"FAF-1031021-BV" ,"",				   {F_OBEX, 0}},
+	{"GC89",	"FAF-1051011-BV" ,"",				   {F_OBEX, 0}},
+	{"GC86",	"FAF-1051012-BV" ,"",				   {F_OBEX, 0}},
+
+	/* IrDA identifications for Sony-Ericsson */
+	/* At least my K750i reports itself as "Sony Ericss", so detect it for IrDA */
+	{"Generic SE",	"Generic SE", "Sony Ericss",			   {F_OBEX, 0}},
+	{"K300 series",	"K300 series", "K300 series",			   {F_OBEX, 0}},
+
+	/* Mitsubishi */
+	{"M341i",	"M7", "",					   {F_OBEX, F_IRMC_LEVEL_2, 0}},
+
 	/* Other */
 	{"iPAQ" ,	  "iPAQ"  ,	  "" ,				   {0}},
 	{"A2D"  ,	  "A2D"  ,	  "" ,				   {0}},
