@@ -40,6 +40,9 @@ typedef struct _GSM_Reply_Function	GSM_Reply_Function;
 #ifdef GSM_ENABLE_ALCATEL
 #  include "phone/alcatel/alcatel.h"
 #endif
+#ifdef GSM_ENABLE_SONYERICSSON
+#  include "phone/sonyeric/sonyeric.h"
+#endif
 #ifdef GSM_ENABLE_OBEXGEN
 #  include "phone/obex/obexgen.h"
 #endif
@@ -812,6 +815,9 @@ typedef struct {
 #ifdef GSM_ENABLE_ALCATEL
 		GSM_Phone_ALCATELData	 ALCATEL;
 #endif
+#ifdef GSM_ENABLE_SONYERICSSON
+		GSM_Phone_SONYERICSSONData	 SONYERICSSON;
+#endif
 #ifdef GSM_ENABLE_OBEXGEN
 		GSM_Phone_OBEXGENData	 OBEXGEN;
 #endif
@@ -1421,6 +1427,9 @@ typedef struct {
 #ifdef GSM_ENABLE_ALCATEL
 	extern GSM_Phone_Functions ALCATELPhone;
 #endif
+#ifdef GSM_ENABLE_SONYERICSSON
+	extern GSM_Phone_Functions SONYERICSSONPhone;
+#endif
 #ifdef GSM_ENABLE_OBEXGEN
 	extern GSM_Phone_Functions OBEXGENPhone;
 #endif
@@ -1491,6 +1500,11 @@ typedef struct {
 	bool			DefaultDebugFile;
 	bool			DefaultLocalize;
 	bool			DefaultStartInfo;
+	char			TextReminder[32];	/* Text for calendar entry categories in local language */
+	char			TextMeeting[32];
+	char			TextCall[32];
+	char			TextBirthday[32];
+	char			TextMemo[32];
 } GSM_Config;
 
 #define MAX_CONFIG_NUM		5
@@ -1587,6 +1601,7 @@ typedef enum {
 	F_CHAT,		/* Phone with Chat settings 					*/
 	F_SYNCML,	/* Phone with SyncML settings 					*/
 	F_FILES2,	/* filesystem version 2 					*/
+	F_NOFILE1,
 	F_6230iWAP,	/* WAP, MMS, etc. settings like in 6230i - unknown now		*/
 	F_PROFILES,	/* Profiles support available					*/
 	F_SERIES40_30,  /* Series 40 3.0						*/
@@ -1604,7 +1619,9 @@ typedef enum {
 	F_M20SMS,	/* Siemens M20 like SMS handling				*/
 	F_SLOWWRITE,	/* Use slower writing which some phone need			*/
 	F_SMSME900,	/* SMS in ME start from location 900 - case of Sagem		*/
-	F_ALCATEL	/* Phone supports Alcatel protocol				*/
+	F_ALCATEL,	/* Phone supports Alcatel protocol				*/
+	F_OBEX,		/* Phone can switch to OBEX protocol from AT mode		*/
+	F_IRMC_LEVEL_2,	/* Phone supports IrMC level 2 even if it doesn't report it	*/
 } Feature;
 
 /* For models table */
