@@ -305,6 +305,10 @@ static GSM_Error N6510_GetFileSystemStatus1(GSM_StateMachine *s, GSM_FileSystemS
 		0x00, 0x00, 0x01,
 		0x00, 0x01};    /* Folder or file number */
 
+	/* Used memory by types */
+	status->UsedImages = 0;
+	status->UsedSounds = 0;
+	status->UsedThemes = 0;
 	s->Phone.Data.FileSystemStatus = status;
 
 	status->Free = 0;
@@ -370,7 +374,7 @@ static GSM_Error N6510_GetFilePart1(GSM_StateMachine *s, GSM_File *File, int *Ha
 static GSM_Error N6510_SetReadOnly1(GSM_StateMachine *s, unsigned char *ID, bool enable)
 {
 	unsigned char SetAttr[] = {
-		N7110_FRAME_HEADER, 0x18, 
+		N7110_FRAME_HEADER, 0x18,
 		0x00, 		    /* state */
 		0x00, 0x00, 0x01,
 		0x00, 0x20};	    /* File ID */
@@ -398,8 +402,8 @@ static GSM_Error N6510_SetFileAttributes1(GSM_StateMachine *s, GSM_File *File)
 	if (file2.Folder) return ERR_SHOULDBEFILE;
 
 	// todo
-	if (file2.System != File->System || 
-	    file2.Hidden != File->Hidden || 
+	if (file2.System != File->System ||
+	    file2.Hidden != File->Hidden ||
 	    file2.Protected != File->Protected) {
 		return ERR_NOTSUPPORTED;
 	}
@@ -1216,8 +1220,8 @@ static GSM_Error N6510_SetFileAttributes2(GSM_StateMachine *s, GSM_File *File)
 	if (error != ERR_NONE) return error;
 
 	//mmc doesn't support protected
-	if (File2.System    != File->System     || 
-	    File2.ReadOnly  != File->ReadOnly   || 
+	if (File2.System    != File->System     ||
+	    File2.ReadOnly  != File->ReadOnly   ||
 	    File2.Hidden    != File->Hidden     ) {
 //	    File2.Protected != File->Protected) {
 		return ERR_NOTSUPPORTED;
@@ -1334,9 +1338,9 @@ static GSM_Error N6510_GetFolderListing2(GSM_StateMachine *s, GSM_File *File, bo
 	int			i;
 
 	if (start) {
-		if (mystrncasecmp(DecodeUnicodeString(File->ID_FullName),"a:",0)   || 
+		if (mystrncasecmp(DecodeUnicodeString(File->ID_FullName),"a:",0)   ||
 		    mystrncasecmp(DecodeUnicodeString(File->ID_FullName),"a:\\",0) ||
-		    mystrncasecmp(DecodeUnicodeString(File->ID_FullName),"d:",0)   || 
+		    mystrncasecmp(DecodeUnicodeString(File->ID_FullName),"d:",0)   ||
 		    mystrncasecmp(DecodeUnicodeString(File->ID_FullName),"d:\\",0)) {
 		} else {
 			//we must check, if user gave folder name or not
@@ -1522,8 +1526,13 @@ GSM_Error N6510_GetFolderListing(GSM_StateMachine *s, GSM_File *File, bool start
 
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' || 
+	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' ||
 	    DecodeUnicodeString(File->ID_FullName)[0] == 'C') {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
+
 		memcpy(&File2,File,sizeof(GSM_File));
 		CopyUnicodeString(File2.ID_FullName,File->ID_FullName+3*2);
 		error = N6510_GetFolderListing1(s,&File2,start);
@@ -1550,11 +1559,13 @@ GSM_Error N6510_GetNextFileFolder(GSM_StateMachine *s, GSM_File *File, bool star
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
 	if (start) {
+		Priv->Use2 = true;
 		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30)) {
 			//series 40 3.0 don't have filesystem 1
 			Priv->Use2 = false;
-		} else {
-			Priv->Use2 = true;
+		}
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			Priv->Use2 = false;
 		}
 	}
 	if (Priv->Use2) {
@@ -1569,7 +1580,7 @@ GSM_Error N6510_GetNextFileFolder(GSM_StateMachine *s, GSM_File *File, bool star
 			if (error == ERR_NONE) {
 				sprintf(buf,"c:/%s",DecodeUnicodeString(File->ID_FullName));
 				EncodeUnicode(File->ID_FullName,buf,strlen(buf));
-				
+
 				if (File->Level != 1) return error;
 
 				buf[0] = 0;
@@ -1593,9 +1604,10 @@ GSM_Error N6510_GetFilePart(GSM_StateMachine *s, GSM_File *File, int *Handle, in
 
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' || 
+	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' ||
 	    DecodeUnicodeString(File->ID_FullName)[0] == 'C') {
-		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30)) {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
 			return ERR_NOTSUPPORTED;
 		}
 		memcpy(&File2,File,sizeof(GSM_File));
@@ -1621,8 +1633,13 @@ GSM_Error N6510_AddFilePart(GSM_StateMachine *s, GSM_File *File, int *Pos, int *
 
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' || 
+	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' ||
 	    DecodeUnicodeString(File->ID_FullName)[0] == 'C') {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
+
 		memcpy(&File2,File,sizeof(GSM_File));
 		CopyUnicodeString(File2.ID_FullName,File->ID_FullName+3*2);
 		error = N6510_AddFilePart1(s,&File2,Pos,Handle);
@@ -1644,8 +1661,13 @@ GSM_Error N6510_DeleteFile(GSM_StateMachine *s, unsigned char *ID)
 {
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(ID)[0] == 'c' || 
+	if (DecodeUnicodeString(ID)[0] == 'c' ||
 	    DecodeUnicodeString(ID)[0] == 'C') {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
+
 		return N6510_DeleteFile1(s,ID+6);
 	} else {
 		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_FILES2)) {
@@ -1663,8 +1685,12 @@ GSM_Error N6510_AddFolder(GSM_StateMachine *s, GSM_File *File)
 
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' || 
+	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' ||
 	    DecodeUnicodeString(File->ID_FullName)[0] == 'C') {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
 		memcpy(&File2,File,sizeof(GSM_File));
 		CopyUnicodeString(File2.ID_FullName,File->ID_FullName+3*2);
 		error = N6510_AddFolder1(s,&File2);
@@ -1686,8 +1712,12 @@ GSM_Error N6510_DeleteFolder(GSM_StateMachine *s, unsigned char *ID)
 {
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(ID)[0] == 'c' || 
+	if (DecodeUnicodeString(ID)[0] == 'c' ||
 	    DecodeUnicodeString(ID)[0] == 'C') {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
 		return N6510_DeleteFolder1(s,ID+6);
 	} else {
 		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_FILES2)) {
@@ -1705,6 +1735,10 @@ GSM_Error N6510_GetFileSystemStatus(GSM_StateMachine *s, GSM_FileSystemStatus *s
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_FILES2)) {
 		return ERR_NOTSUPPORTED;
 	} else {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
 		return N6510_GetFileSystemStatus1(s,status);
 	}
 }
@@ -1717,8 +1751,12 @@ GSM_Error N6510_SetFileAttributes(GSM_StateMachine *s, GSM_File *File)
 
 	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILESYSTEM)) return ERR_NOTSUPPORTED;
 
-	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' || 
+	if (DecodeUnicodeString(File->ID_FullName)[0] == 'c' ||
 	    DecodeUnicodeString(File->ID_FullName)[0] == 'C') {
+		if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+		    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
+			return ERR_NOTSUPPORTED;
+		}
 		memcpy(&File2,File,sizeof(GSM_File));
 		CopyUnicodeString(File2.ID_FullName,File->ID_FullName+3*2);
 		error = N6510_SetFileAttributes1(s,&File2);
@@ -1745,7 +1783,8 @@ GSM_Error N6510_GetNextRootFolder(GSM_StateMachine *s, GSM_File *File)
 
 	memset(&File2, 0, sizeof(File2));
 
-	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30)) {
+	if (IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SERIES40_30) ||
+	    IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_NOFILE1)) {
 		if (UnicodeLength(File->ID_FullName) == 0) {
 			EncodeUnicode(File->ID_FullName,"d:",2);
 			EncodeUnicode(File->Name,"D (Permanent_memory 2)",22);
@@ -1761,7 +1800,7 @@ GSM_Error N6510_GetNextRootFolder(GSM_StateMachine *s, GSM_File *File)
 		return ERR_NONE;
 	}
 
-	if (UnicodeLength(File->ID_FullName) == 0) {	
+	if (UnicodeLength(File->ID_FullName) == 0) {
 		sprintf(buffer,"%i",0x01);
 		EncodeUnicode(File2.ID_FullName,buffer,strlen(buffer));
 		File2.Level = 1;
@@ -1802,7 +1841,7 @@ GSM_Error N6510_GetNextRootFolder(GSM_StateMachine *s, GSM_File *File)
 	} else if (!strcmp(DecodeUnicodeString(File->ID_FullName),"c:\\1")) {
 		return ERR_EMPTY;
 	}
-	return ERR_NONE;	
+	return ERR_NONE;
 }
 
 GSM_Error N6510_PrivGet3220FilesystemMMSFolders(GSM_StateMachine *s, GSM_MMSFolders *folders)
@@ -2012,7 +2051,7 @@ GSM_Error N6510_GetNextMMSFileInfo(GSM_StateMachine *s, unsigned char *FileID, i
 		Priv->MMSFolderError 	= ERR_EMPTY;
 	}
 
-	while(true) {	
+	while(true) {
 		if (Priv->MMSFolderError == ERR_NONE) {
 			Priv->MMSFolderError = N6510_GetFolderListing(s,&Priv->MMSFile,false);
 			if (Priv->MMSFolderError != ERR_EMPTY && Priv->MMSFolderError != ERR_NONE) return Priv->MMSFolderError;
@@ -2021,10 +2060,10 @@ GSM_Error N6510_GetNextMMSFileInfo(GSM_StateMachine *s, unsigned char *FileID, i
 		if (Priv->MMSFolderError == ERR_EMPTY) {
 			while (1) {
 				if (UnicodeLength(Priv->MMSFoldersID2[Priv->MMSFolderNum])==0) return ERR_EMPTY;
-	
+
 				CopyUnicodeString(Priv->MMSFile.ID_FullName,Priv->MMSFoldersID2[Priv->MMSFolderNum]);
 				Priv->MMSFolderNum++;
-	
+
 				Priv->MMSFolderError = N6510_GetFolderListing(s,&Priv->MMSFile,true);
 				if (Priv->MMSFolderError == ERR_EMPTY) continue;
 				if (Priv->MMSFolderError != ERR_NONE) return Priv->MMSFolderError;
@@ -2046,7 +2085,7 @@ GSM_Error N6510_GetNextMMSFileInfo(GSM_StateMachine *s, unsigned char *FileID, i
 			} else {
 				return error;
 			}
-	
+
 			//0x00 = SMS, 0x01,0x03 = MMS
 			if (file.Buffer[6] != 0x00) {
 				free(file.Buffer);
@@ -2195,9 +2234,17 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 		FFF.ID_FullName[0] = 0;
 		FFF.ID_FullName[1] = 0;
 		CopyUnicodeString(FFF.ID_FullName,Priv->SMSFile.ID_FullName);
-		smprintf(s,"sms file name is %s\n",DecodeUnicodeString(FFF.ID_FullName));	
+		smprintf(s,"sms file name is %s\n",DecodeUnicodeString(FFF.ID_FullName));
 		error = ERR_NONE;
-		while (error == ERR_NONE) error = N6510_GetFilePart(s,&FFF,&Handle,&Size);
+		while (error == ERR_NONE) {
+			error = N6510_GetFilePart(s,&FFF,&Handle,&Size);
+			//if mms, don't read all
+			if (error==ERR_NONE && FFF.Used>5 && FFF.Buffer[6] != 0x00) {
+				error = N6510_CloseFile2(s, &Handle);
+				if (error != ERR_NONE) return error;
+				break;
+			}
+		}
 		DumpMessage(&s->di, FFF.Buffer, FFF.Used);
 
 		//0x00 = SMS, 0x01,0x03 = MMS
@@ -2214,6 +2261,7 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 	Layout.TPDCS = 255;
 	smprintf(s,"file type %02x\n",FFF.Buffer[i]);
 	switch (FFF.Buffer[i]) {
+	case 0x00:
 	case 0x04:
 	case 0x20:
 	case 0x24:
@@ -2252,7 +2300,8 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 		sms->Number = 1;
 		CopyUnicodeString(sms->SMS[0].Number,FFF.Buffer+94);
 		i+=UnicodeLength(sms->SMS[0].SMSC.Number);
-		if(FFF.Buffer[176]!=0x20) i+=4;
+		//if(FFF.Buffer[176]!=0x20)
+		i+=4;
 		CopyUnicodeString(sms->SMS[0].Name,FFF.Buffer+i);
 		break;
 	case 0x11:
@@ -2293,7 +2342,16 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 	case 0x31:
 		smprintf(s,"sms sent\n");
 		CopyUnicodeString(sms->SMS[0].Number,FFF.Buffer+94);
-		i+=15;
+		if (sms->SMS[0].Number[0]==0x00 && sms->SMS[0].Number[1]==0x00) {
+			smprintf(s,"%02x\n",FFF.Buffer[i+2]);
+			//semioctets to chars in phone number
+			if (FFF.Buffer[i+2] % 2) FFF.Buffer[i+2]++;
+			FFF.Buffer[i+2]=FFF.Buffer[i+2] / 2 + 1;
+			smprintf(s,"number avail. %i\n",FFF.Buffer[i+2]+2);
+			i+=FFF.Buffer[i+2]+4;
+		} else {
+			i+=15;
+		}
 		Layout.firstbyte = 1; //fixme
 		smprintf(s,"TPDCS %02x\n",FFF.Buffer[i]);
 		Layout.TPDCS=i;
@@ -2321,13 +2379,43 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 		sms->SMS[0].State = SMS_Sent;
 		sms->Number = 1;
 		CopyUnicodeString(sms->SMS[0].Name,FFF.Buffer+i);
+		if (sms->SMS[0].Number[0]==0x00 && sms->SMS[0].Number[1]==0x00) {
+			i+=UnicodeLength(sms->SMS[0].Name)*2+5;
+			while (true) {
+				if (FFF.Buffer[i+1]==0x00) break;
+				smprintf(s,"recipient number %02x %02x",FFF.Buffer[i],FFF.Buffer[i+1]);
+				if (sms->SMS[0].Number[0]==0x00 && sms->SMS[0].Number[1]==0x00) {
+					CopyUnicodeString(sms->SMS[0].Number,FFF.Buffer+i);
+					smprintf(s,"%s\n",DecodeUnicodeString(sms->SMS[0].Number));
+					i+=UnicodeLength(sms->SMS[0].Number)*2+13;
+				} else {
+					CopyUnicodeString(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum],FFF.Buffer+i);
+					smprintf(s,"%s\n",DecodeUnicodeString(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum]));
+					i+=UnicodeLength(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum])*2+13;
+					sms->SMS[0].OtherNumbersNum++;
+				}
+			}
+		}
 		break;
 	case 0x51:
 	case 0x71:
 		smprintf(s,"sms sent with udh\n");
 		Layout.firstbyte = i;
 		CopyUnicodeString(sms->SMS[0].Number,FFF.Buffer+94);
-		i+=15;
+		if (sms->SMS[0].Number[0]==0x00 && sms->SMS[0].Number[1]==0x00) {
+			smprintf(s,"%02x\n",FFF.Buffer[i+2]);
+			if (FFF.Buffer[176]==0x71) {
+				GSM_UnpackSemiOctetNumber(sms->SMS[0].Number,FFF.Buffer+i+2 , true);
+			}
+			//semioctets to chars in phone number
+			if (FFF.Buffer[i+2] % 2) FFF.Buffer[i+2]++;
+			FFF.Buffer[i+2]=FFF.Buffer[i+2] / 2 + 1;
+			smprintf(s,"number avail. %i\n",FFF.Buffer[i+2]+2);
+			i+=FFF.Buffer[i+2]+4;
+		} else {
+			i+=15;
+		}
+
 		smprintf(s,"TPDCS %02x\n",FFF.Buffer[i]);
 		Layout.TPDCS=i;
 		i+=2;
@@ -2348,6 +2436,27 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 			i+=FFF.Buffer[i];
 		}
 		i+=11;
+		if (sms->SMS[0].Number[0]==0x00 && sms->SMS[0].Number[1]==0x00) {
+			if (FFF.Buffer[176]==0x51) {
+				CopyUnicodeString(sms->SMS[0].Name,FFF.Buffer+i);
+				i+=UnicodeLength(sms->SMS[0].Name)*2+5;
+				while (true) {
+					if (FFF.Buffer[i+1]==0x00) break;
+					smprintf(s,"recipient number %02x %02x",FFF.Buffer[i],FFF.Buffer[i+1]);
+					if (sms->SMS[0].Number[0]==0x00 && sms->SMS[0].Number[1]==0x00) {
+						CopyUnicodeString(sms->SMS[0].Number,FFF.Buffer+i);
+						smprintf(s,"%s\n",DecodeUnicodeString(sms->SMS[0].Number));
+						i+=UnicodeLength(sms->SMS[0].Number)*2+13;
+					} else {
+						CopyUnicodeString(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum],FFF.Buffer+i);
+						smprintf(s,"%s\n",DecodeUnicodeString(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum]));
+						i+=UnicodeLength(sms->SMS[0].OtherNumbers[sms->SMS[0].OtherNumbersNum])*2+13;
+						sms->SMS[0].OtherNumbersNum++;
+					}
+				}
+			}
+		}
+
 		sms->SMS[0].PDU = SMS_Deliver;
 		sms->SMS[0].Class = -1;//fixme
 		sms->SMS[0].State = SMS_Sent;
@@ -2368,11 +2477,14 @@ GSM_Error N6510_GetNextFilesystemSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *s
 		CopyUnicodeString(sms->SMS[0].Number,FFF.Buffer+94);
 		Layout.TPDCS=i+2;
 		smprintf(s,"TPDCS %02x\n",FFF.Buffer[i+2]);
-		i+=10;
-		smprintf(s,"TPUDL %02x %02x\n",FFF.Buffer[i],FFF.Buffer[i+1]);
-		Layout.TPUDL = i+1;
-		Layout.Text = i+2;
+		smprintf(s,"TPUDL %02x\n",FFF.Buffer[i+11]);
+		Layout.TPUDL = i+11;
+		Layout.Text = i+12;
 		GSM_DecodeSMSFrameText(&sms->SMS[0], FFF.Buffer, Layout);
+		if (FFF.Buffer[176]!=0x64) {
+			i+=FFF.Buffer[Layout.TPUDL];
+			EncodeUnicode(sms->SMS[0].SMSC.Number,FFF.Buffer+i+2,FFF.Buffer[i+1]);
+		}
 		sms->SMS[0].PDU = SMS_Deliver;
 		sms->SMS[0].Class = -1;//fixme
 		sms->SMS[0].State = SMS_Sent;
